"use strict";
const { getWindowsSize } = require('./lib/Common');
const { initEyesSdk } = require('./lib/Applitools');
const codeceptjs_1 = require("codeceptjs");
const merge = require('deepmerge');
let windowsSize;
let client;
let _helper;
const supportedHelper = ['Playwright', 'WebDriver', 'Puppeteer'];
const defaultConfig = {
    appName: 'Application Under Test',
    batchInfo: 'Visual Tests with the Classic Runner',
};
class ApplitoolsHelper extends codeceptjs_1.Helper {
    constructor(config) {
        super(config);
        if (!config.apiKey)
            throw Error('Please check your Applitools API key!');
        this.config = merge(defaultConfig, config);
    }
    async _before() {
        for (const item of supportedHelper) {
            if (this.helpers[item]) {
                _helper = item;
                break;
            }
        }
        if (!_helper)
            throw Error(`Unsupported Helper! Supported helpers are ${supportedHelper.join(',')}`);
        this.helpers[_helper].config.manualStart = true;
        this.helpers[_helper].options.manualStart = true;
        if (this.config.windowSize) {
            windowsSize = getWindowsSize(this.config);
        }
        else if (this.helpers[_helper].config.windowSize) {
            windowsSize = getWindowsSize(this.helpers[_helper].config);
        }
        else {
            windowsSize = { width: 1920, height: 600 };
        }
        if (client) {
            await this.helpers[_helper]._stopBrowser();
        }
        client = this.helpers[_helper].page
            ? this.helpers[_helper].page
            : this.helpers[_helper].browser;
    }
    /**
     * Visual check using the eyeCheck method
     *
     */
    async eyeCheck({ pageName, element, uniqueId, matchLevel, }) {
        const { eyes, Target, Runner } = initEyesSdk(_helper.toLowerCase(), this.config);
        if (uniqueId) {
            eyes.setBatch(pageName, uniqueId);
        }
        if (matchLevel) {
            eyes.setMatchLevel(matchLevel);
        }
        await eyes.open(client, this.config.appName, pageName, windowsSize);
        if (element) {
            eyes.setForceFullPageScreenshot(false);
            await eyes.check(pageName, Target.region(element));
        }
        else {
            await eyes.check(pageName, Target.window().fully().layout());
        }
        await eyes.closeAsync();
        await Runner.getAllTestResults();
    }
}
module.exports = ApplitoolsHelper;
//# sourceMappingURL=index.js.map